@@ -6,7 +6,7 @@ overallComponentsPlot <- function(comp, ref){
   barplot(t(diffMR[2:4]), ylab="Difference (percent of domain)")
   
   par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0), mar = c(0, 0, 0, 0), new = TRUE)
-  plot(0, 0, type = "n", bty = "n", xaxt = "n", yaxt = "n")
+  graphics::plot(0, 0, type = "n", bty = "n", xaxt = "n", yaxt = "n")
   legend(x=0.1, y=0.3, c(colnames(diffMR)[4:2]), bty="n", 
          fill = c(rgb(230,230,230, maxColorValue=255), rgb(174,174,174, maxColorValue=255), 
                   rgb(77,77,77, maxColorValue=255)))
